@@ -34,7 +34,7 @@ lystig <- function(init,A,B,ntimes=NULL,stationary=TRUE) {
 		et <- cumsum(ntimes)
 		bt <- c(1,et[-lt]+1)
 				
-		ll <- 0		
+# 		ll <- 0	
 		
 		for(case in 1:lt) { # multiple cases
 			phi[bt[case],] <- init[case,]*B[bt[case],] # initialize case
